==> hermes-5.9.0.18.tar.gz: hermes-5.9.0.18/lib/hermes.rb <==
require 'hermes/engine'
require 'hermes/bo_client'
require 'hermes/rex_client'

require 'mongo'
require 'nokogiri'
require 'awesome_print'

def recurs_require(path, from = nil)
  target_path = [from, path].compact.join('/')
  if File.directory?(target_path)
    Dir["#{target_path}/*"].each do |elt|
      recurs_require elt
    end
  elsif File.file? target_path
    require target_path
  else
    puts "#{target_path} is neither directory nor file"
  end
end

recurs_require [__dir__, 'extras'].flatten.join('/')
#recurs_require [__dir__, %w[hermes bo_client]].flatten.join('/')
=begin
def rebase_xs_include_for(arr)
  project_root = __dir__.sub('/lib', '')
  xsds = arr.map do |path|
    real_path = [project_root, path].flatten.join('/')
    raise ArgumentError.new("#{real_path} does not exists.") unless File.file?(real_path)

    File.open(real_path, 'r+')
  end

  xs_include_regexp = /(<xs:include.+schemaLocation=")(((?!").)+)/
  arr.map do |path|
    real_path = [project_root, path].flatten.join('/')
    raise ArgumentError.new("#{real_path} does not exists.") unless File.file?(real_path)

    File.open(real_path, 'r+') do |xsd|
      xsd_str = xsd.read
      rerouted_xsd_str = xsd_str.gsub(xs_include_regexp) do
        match_one = Regexp.last_match(1)
        match_two = Regexp.last_match(2)
        relative_path = if match_two.match('/hermes')
                          match_two[(match_two.index('/hermes') + 7)..-1]
                        else
                          match_two
                        end
        puts "rerouted ns:include to #{match_one + project_root + relative_path}"
        "#{match_one}#{project_root}#{relative_path}"
      end
      xsd.rewind
      xsd.write(rerouted_xsd_str)
    end
  end
end


rebase_xs_include_for %w[
  spec/libs/bo_client/tasks/InterfaceNuu_v0300.xsd
]
=end



module Hermes
  class Application < Rails::Application
    config.after_initialize do
      recurs_require [__dir__, './../app/overrides/models'].flatten.join('/')
        #require_relative "./../app/overrides/models/user_override.rb"
    end
    config.middleware.use Rack::Deflater
  end
  # Your code goes here...

end

==> hermes-5.9.0.19.tar.gz: hermes-5.9.0.19/lib/hermes.rb <==
require 'hermes/engine'
require 'hermes/bo_client'
require 'hermes/rex_client'

require 'mongo'
require 'nokogiri'
require 'awesome_print'

def recurs_require(path, from = nil)
  target_path = [from, path].compact.join('/')
  if File.directory?(target_path)
    Dir["#{target_path}/*"].each do |elt|
      recurs_require elt
    end
  elsif File.file? target_path
    require target_path
  else
    puts "#{target_path} is neither directory nor file"
  end
end

recurs_require [__dir__, 'extras'].flatten.join('/')
#recurs_require [__dir__, %w[hermes bo_client]].flatten.join('/')
=begin
def rebase_xs_include_for(arr)
  project_root = __dir__.sub('/lib', '')
  xsds = arr.map do |path|
    real_path = [project_root, path].flatten.join('/')
    raise ArgumentError.new("#{real_path} does not exists.") unless File.file?(real_path)

    File.open(real_path, 'r+')
  end

  xs_include_regexp = /(<xs:include.+schemaLocation=")(((?!").)+)/
  arr.map do |path|
    real_path = [project_root, path].flatten.join('/')
    raise ArgumentError.new("#{real_path} does not exists.") unless File.file?(real_path)

    File.open(real_path, 'r+') do |xsd|
      xsd_str = xsd.read
      rerouted_xsd_str = xsd_str.gsub(xs_include_regexp) do
        match_one = Regexp.last_match(1)
        match_two = Regexp.last_match(2)
        relative_path = if match_two.match('/hermes')
                          match_two[(match_two.index('/hermes') + 7)..-1]
                        else
                          match_two
                        end
        puts "rerouted ns:include to #{match_one + project_root + relative_path}"
        "#{match_one}#{project_root}#{relative_path}"
      end
      xsd.rewind
      xsd.write(rerouted_xsd_str)
    end
  end
end


rebase_xs_include_for %w[
  spec/libs/bo_client/tasks/InterfaceNuu_v0300.xsd
]
=end



module Hermes
  class Application < Rails::Application
    config.after_initialize do
      recurs_require [__dir__, './../app/overrides/models'].flatten.join('/')
        #require_relative "./../app/overrides/models/user_override.rb"
    end
    config.middleware.insert_before Rack::Sendfile, Rack::Deflater
  end
  # Your code goes here...

end
